@@ -76,9 +76,17 @@
   #}
 
   if (classic==TRUE) {
-    assign(paste("xpdb", object@Runno, sep = ""), object, immediate=T, envir = .GlobalEnv)
-    assign(pos = 1, ".cur.db", eval(as.name(paste("xpdb", object@Runno, sep = ""))))
+    #     assign(paste("xpdb", object@Runno, sep = ""), object, immediate=T, envir = .GlobalEnv)
+    #     assign(pos = 1, ".cur.db", eval(as.name(paste("xpdb", object@Runno, sep = ""))))
+    #     return(cat(""))
+    
+    ## to avoid checks on global variable assignment in package building
+    c1<-call("assign",paste("xpdb", object@Runno, sep = ""),object,envir=.GlobalEnv)
+    eval(c1)
+    c2<-call("assign",pos = 1, ".cur.db", eval(as.name(paste("xpdb", object@Runno, sep = ""))))
+    eval(c2)
     return(cat(""))
+    
   } else {
     return(object)
   }
