@@ -55,8 +55,10 @@ change.dv.cat.levels <- function(object,
     object@Prefs@DV.Cat.levels <- ans
     Data(object) <- object@Data
     if (classic==TRUE) {
-      assign(paste("xpdb", object@Runno, sep = ""), object, immediate=T, envir = .GlobalEnv)
-      assign(pos = 1, ".cur.db", eval(as.name(paste("xpdb", object@Runno, sep = ""))))
+      c1<-call("assign",paste("xpdb", object@Runno, sep = ""), data, immediate=T, envir = .GlobalEnv)
+      eval(c1)
+      c2<-call("assign",pos = 1, ".cur.db", eval(as.name(paste("xpdb", object@Runno, sep = ""))))
+      eval(c2)
     }
   }
   return(object)
