@@ -40,9 +40,12 @@
     }
   
   if (classic==TRUE) {
-    assign(paste("xpdb", xpobj@Runno, sep = ""), xpobj, immediate=T, envir = .GlobalEnv)
-    assign(pos = 1, ".cur.db", eval(as.name(paste("xpdb", xpobj@Runno, sep = ""))))
+    c1<-call("assign",paste("xpdb", object@Runno, sep = ""), data, immediate=T, envir = .GlobalEnv)
+    eval(c1)
+    c2<-call("assign",pos = 1, ".cur.db", eval(as.name(paste("xpdb", object@Runno, sep = ""))))
+    eval(c2)
     return(cat(""))
+    
   } else {
     return(xpobj)
   }
